reset_inference_state

Function reset_inference_state 

pub fn reset_inference_state()
Clears inference bookkeeping left behind when a previous compilation on this thread was aborted by an error unwind (see errors::collect_diagnostic).